package com.zhentao.lianxi330.model;

import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.*;
import java.time.LocalDateTime;
import java.time.ZoneOffset;
import java.util.Date;

@Data
public class RequestParams {

    @NotBlank(message = "appId 不能为空")
    private String appId;

    @NotBlank(message = "sign 不能为空")
    private String sign;

    @NotNull(message = "reqTime 不能为空")
    private Long reqTime;

    @NotBlank(message = "goodsId 不能为空")
    private String goodsId;

    @NotNull(message = "amount 不能为空")
    @Min(value = 1, message = "amount 必须大于等于 1")
    private Integer amount;

    @NotNull(message = "price 不能为空")
    @Min(value = 0, message = "price 必须大于等于 0")
    @Max(value = 9999, message = "price 必须小于等于 9999")
    private Double price;

    @NotBlank(message = "mobile 不能为空")
    @Pattern(regexp = "^1[3-9]\\d{9}$", message = "手机号码格式不正确")
    private String mobile;

    @NotNull(message = "nowDate 不能为空")
    @DateTimeFormat(iso = DateTimeFormat.ISO.DATE_TIME)
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private String nowDate;
}
